@@ -16,8 +16,8 @@ def sumdumbfun(x,y): # this is only here to test the package during development
 ## RootDir establishes the export and data folder structure
 def RootDir(corename, Formation_names):
     root_dir = 'CorePy'
-    main_dir = ['CoreData', 'CoreOutput', 'CoreTubes']
-    sub_dir= ['CoreAttributes', 'CoreXRF','CoreBoxPhotos']    
+    main_dir = ['CoreData', 'CoreOutput']
+    sub_dir= ['CoreAttributes', 'CoreXRF','CoreBoxPhotos', 'CoreTubes']    
         
     for i in range(0, len(main_dir)):
         dirName = str(root_dir) + '/' + str(main_dir[i])
@@ -139,4 +139,18 @@ def cropCorebox(cropArea, imageFileName,imageFolder,newFolderPath):
     croppedimagePath = os.path.join(newFolderPath, imageFileName)
     imgCrop.save(croppedimagePath)
     imgOpen.close()
- 
\ No newline at end of file
+ 
+def ImageDir(corename):
+    root_dir = 'CorePy'
+    main_dir = ['CoreData']
+    sub_dir= ['CoreBoxPhotos','CoreTubes']
+    
+    for i in range(0, len(main_dir)):
+        dirName = str(root_dir) + '/' + str(main_dir[i])
+        if not os.path.exists(dirName):
+            os.makedirs(dirName)
+            
+    for i in range(0, len(sub_dir)):
+        dirName = str(root_dir) + '/' + str(main_dir[0]) + '/' + str(sub_dir[i])
+        if not os.path.exists(dirName):
+		        os.makedirs(dirName)
\ No newline at end of file
